@@ -281,6 +281,9 @@ providers_list = {
     'japscan_com': [
         r'japscan\.(cc|com|co|to|se)/.',
     ],
+    'jmana_net': [
+        r'jmana\d+\.net/book\?bookid=\d',
+    ],
     'jurnalu_ru': [
         r'jurnalu\.ru/online-reading/.',
     ],
@@ -475,6 +478,9 @@ providers_list = {
     'mangatail_com': [
         r'mangatail\.me/(manga|chapter|node|content)/.',
     ],
+    'manatoki_net': [
+        r'manatoki\d+\.net/comic/\d',
+    ],
     'mangatown_com': [
         r'mangatown\.com/manga/.',
     ],
@@ -605,8 +611,10 @@ providers_list = {
     ],
     'readmanga_me': [
         r'readmanga\.live/.',
+        r'readmanga\.io/.',
         r'mintmanga\.live/.',
         r'selfmanga\.ru/.',
+        r'selfmanga\.live/.',
     ],
     'readmng_com': [
         r'readmng\.com/.',
