@@ -11,7 +11,7 @@ class HentaiPornsNet(Provider, Std):
     def get_chapter_index(self) -> str:
         return '0'
 
-    def get_main_content(self):
+    def get_content(self):
         url = self.get_url()
         if ~url.find('/tag/'):
             self.log('Please, use target url', file=stderr)
