@@ -7,7 +7,7 @@ class MangaAe(Provider, Std):
     def get_chapter_index(self) -> str:
         return self.re.search(r'\.\w{2,7}/[^/]+/(\d+)', self.chapter).group(1)
 
-    def get_main_content(self):
+    def get_content(self):
         return self._get_content('{}/{}/')
 
     def get_manga_name(self) -> str:
