@@ -8,7 +8,7 @@ class MangaIndoWebId(Provider, Std):
         selector = r'-chapter-([^/]+)'
         return self.re.search(selector, self.chapter).group(1)
 
-    def get_main_content(self):
+    def get_content(self):
         return self._get_content('{}/{}/')
 
     def get_manga_name(self) -> str:
