@@ -3,21 +3,23 @@ from .helpers.std import Std
 
 
 class MangaShiroNet(Provider, Std):
+    _main_prefix = None
+
     alter_re_name = r'\.\w{2,7}/([^/]+)-\d+'
     chapter_re = r'\.\w{2,7}/[^/]+-(\d+(?:-\d+)?)'
-    chapters_selector = 'span.leftoff > a'
+    chapters_selector = 'span.leftoff > a,#chapterlist .eph-num > a'
 
     def get_chapter_index(self) -> str:
         chapter = self.chapter
         return self.re.search(self.chapter_re, chapter).group(1)
 
     def get_content(self):
-        return self._get_content('{}/manga/{}/')
+        return self._get_content('{}/%s/{}/' % self._main_prefix)
 
     def get_manga_name(self) -> str:
         url = self.get_url()
-        if ~url.find('/manga/'):
-            re = '/manga/([^/]+)'
+        if ~url.find('/%s/' % self._main_prefix):
+            re = ('/%s/([^/]+)' % self._main_prefix)
         else:
             re = self.alter_re_name
         return self.re.search(re, url).group(1)
@@ -38,9 +40,8 @@ class MangaShiroNet(Provider, Std):
     def get_cover(self) -> str:
         return self._cover_from_content('img.attachment-post-thumbnail')
 
-    def book_meta(self) -> dict:
-        # todo meta
-        pass
+    def prepare_cookies(self):
+        self._main_prefix = self.re.search(r'/(comics?|manga)/', self.get_url()).group(1)
 
 
 main = MangaShiroNet
