@@ -12,7 +12,7 @@ class ReadHentaiMangaCom(Provider, Std):
     def get_chapter_index(self) -> str:
         return self.re.search(r'\.\w{2,7}/[^/]+/([^/]+)', self.chapter).group(1)
 
-    def get_main_content(self):
+    def get_content(self):
         return self._get_content('{}/{}/')
 
     def get_manga_name(self) -> str:
