@@ -9,7 +9,7 @@ class WestMangaInfo(Provider, Std):
         re = self.re.compile(self._chapter_re)
         return re.search(self.chapter).group(1)
 
-    def get_main_content(self):
+    def get_content(self):
         return self._get_content('{}/manga/{}')
 
     def get_manga_name(self) -> str:
